==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/bean/KeyanPlatformEntity.java <==
package com.ejianc.business.sq.keyan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 科研平台
 * 
 * @author generator
 * 
 */
 @TableName("ejc_keyan_platform")
public class KeyanPlatformEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据审批状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="establish_unit_id")
    private Long establishUnitId; // 成立（发起）单位id
    @TableField(value="establish_unit_name")
    private String establishUnitName; // 成立（发起）单位名称
    @TableField(value="level")
    private String level; // 级别
    @TableField(value="platform_type")
    private String platformType; // 平台类型
    @TableField(value="technology_platform_name")
    private String technologyPlatformName; // 科技平台名称
    @TableField(value="establish_time")
    private Date establishTime; // 成立时间
    @TableField(value="approval_unit")
    private String approvalUnit; // 批准单位
    @TableField(value="file_number")
    private String fileNumber; // 文件号
    @TableField(value="research_field")
    private String researchField; // 研究领域
    @TableField(value="remarks")
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEstablishUnitId() {
        return establishUnitId;
    }

    public void setEstablishUnitId(Long establishUnitId) {
        this.establishUnitId = establishUnitId;
    }
    public String getEstablishUnitName() {
        return establishUnitName;
    }

    public void setEstablishUnitName(String establishUnitName) {
        this.establishUnitName = establishUnitName;
    }
    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }
    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }
    public String getTechnologyPlatformName() {
        return technologyPlatformName;
    }

    public void setTechnologyPlatformName(String technologyPlatformName) {
        this.technologyPlatformName = technologyPlatformName;
    }
    public Date getEstablishTime() {
        return establishTime;
    }

    public void setEstablishTime(Date establishTime) {
        this.establishTime = establishTime;
    }
    public String getApprovalUnit() {
        return approvalUnit;
    }

    public void setApprovalUnit(String approvalUnit) {
        this.approvalUnit = approvalUnit;
    }
    public String getFileNumber() {
        return fileNumber;
    }

    public void setFileNumber(String fileNumber) {
        this.fileNumber = fileNumber;
    }
    public String getResearchField() {
        return researchField;
    }

    public void setResearchField(String researchField) {
        this.researchField = researchField;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20251120.093737-47-sources.jar: com/ejianc/business/sq/keyan/bean/KeyanPlatformEntity.java <==
package com.ejianc.business.sq.keyan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 科研平台
 * 
 * @author generator
 * 
 */
 @TableName("ejc_keyan_platform")
public class KeyanPlatformEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据审批状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="establish_unit_id")
    private Long establishUnitId; // 成立（发起）单位id
    @TableField(value="establish_unit_name")
    private String establishUnitName; // 成立（发起）单位名称
    @TableField(value="level")
    private String level; // 级别
    @TableField(value="platform_type")
    private String platformType; // 平台类型
    @TableField(value="technology_platform_name")
    private String technologyPlatformName; // 科技平台名称
    @TableField(value="establish_time")
    private Date establishTime; // 成立时间
    @TableField(value="approval_unit")
    private String approvalUnit; // 批准单位
    @TableField(value="file_number")
    private String fileNumber; // 文件号
    @TableField(value="research_field")
    private String researchField; // 研究领域
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="run_state")
    private String runState; // 运行状态1运行2取消

    public String getRunState() {
        return runState;
    }

    public void setRunState(String runState) {
        this.runState = runState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEstablishUnitId() {
        return establishUnitId;
    }

    public void setEstablishUnitId(Long establishUnitId) {
        this.establishUnitId = establishUnitId;
    }
    public String getEstablishUnitName() {
        return establishUnitName;
    }

    public void setEstablishUnitName(String establishUnitName) {
        this.establishUnitName = establishUnitName;
    }
    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }
    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }
    public String getTechnologyPlatformName() {
        return technologyPlatformName;
    }

    public void setTechnologyPlatformName(String technologyPlatformName) {
        this.technologyPlatformName = technologyPlatformName;
    }
    public Date getEstablishTime() {
        return establishTime;
    }

    public void setEstablishTime(Date establishTime) {
        this.establishTime = establishTime;
    }
    public String getApprovalUnit() {
        return approvalUnit;
    }

    public void setApprovalUnit(String approvalUnit) {
        this.approvalUnit = approvalUnit;
    }
    public String getFileNumber() {
        return fileNumber;
    }

    public void setFileNumber(String fileNumber) {
        this.fileNumber = fileNumber;
    }
    public String getResearchField() {
        return researchField;
    }

    public void setResearchField(String researchField) {
        this.researchField = researchField;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}
